==> photo-translation-hw-1.0.9-sources.jar: com/talpa/translate/base/utils/StaticesConstant.kt <==
package com.talpa.translate.base.utils

/**
 * Create by chenjunsheng on 2020/5/8
 */

const val PT_enter = "PT_enter" //用户进入到图片翻译页面
const val PT_lan_click = "PT_lan_click" //用户点击选择语言框的次数
/*
参数：type
1 ：初始化
2 ：相册识别
3： 相册完成
4： 拍照识别
5： 拍照完成*/
const val type = "type"
const val type_initialize = "1"
const val type_gallery = "2"
const val type_gallery_end = "3"
const val type_camera = "4"
const val type_camera_end = "5"


const val PT_lan_click_success = "PT_lan_click_success" //用户点击选择语言框的选择成功的次数
//1.source_target_language 语言对source_language&target_language
const val source_target_language = "source_target_language"

const val PT_gallery_click = "PT_gallery_click" //用户点击相册的次数

const val PT_gallery_iden_click = "PT_gallery_iden_click" //用户选择相册中图片后点击识别按钮的次数
const val PT_camera_iden_click = "PT_camera_iden_click" //用户拍照后选择完裁剪框点击识别按钮的次数
const val PT_screen_shot_iden_click = "PT_gallery_iden_click" //用户选择相册中图片后点击识别按钮的次数


const val PT_flash_click = "PT_flash_click" //用户打开闪光灯的次数

const val PT_camera_click = "PT_camera_click" //用户拍照的次数

const val PT__gallery_click_success = "PT__gallery_click_success" //用户选择相册中图片后成功识别翻译的次数
const val PT__camera_click_success = "PT__camera_click_success" //用户拍照后成功识别翻译的次数

const val PT__camera_click_fail = "PT__camera_click_fail" //用户拍照后失败的次数
const val PT__gallery_click_fail = "PT__gallery_click_fail" //用户选择相册中图片后失败的次数

const val Trans_start_translate = "Trans_start_translate"
const val Trans_translate_success = "Trans_translate_success"
const val Trans_translate_failure = "Trans_translate_failure"

const val language = "language"
const val moduleType = "moduleType"

const val modulePic = "modulePic"
const val errorMessage = "errorMessage"
/*参数：errorcode
2 ：网络问题
3： 识别超时
4:   翻译错误*/
const val errorcode = "errorcode"
const val NETWORK_PROBLEM = "network_problem"
const val TIMEOUT = "timeout"
const val TRANSLATION_FAIL = "translation_fail"

const val PT_screen_shot_click = "PT_screen_shot_click" //截屏翻译球点击事件

const val NT_notification_click = "NT_notification_click"

const val PT_exit = "PT_exit"
const val PT_lan_click_switch = "PT_lan_click_switch"

==> photo-translation-hw-2.2.15-sources.jar: com/talpa/translate/base/utils/StaticesConstant.kt <==
package com.talpa.translate.base.utils

/**
 * Create by chenjunsheng on 2020/5/8
 */

const val PT_enter = "PT_enter" //用户进入到图片翻译页面
const val PT_lan_click = "PT_lan_click" //用户点击选择语言框的次数
/*
参数：type
1 ：初始化
2 ：相册识别
3： 相册完成
4： 拍照识别
5： 拍照完成*/
const val type = "type"
const val type_initialize = "1"
const val type_gallery = "2"
const val type_gallery_end = "3"
const val type_camera = "4"
const val type_camera_end = "5"


const val PT_lan_click_success = "PT_lan_click_success" //用户点击选择语言框的选择成功的次数
//1.source_target_language 语言对source_language&target_language
const val source_target_language = "source_target_language"

const val PT_gallery_click = "PT_gallery_click" //用户点击相册的次数

const val PT_gallery_iden_click = "PT_gallery_iden_click" //用户选择相册中图片后点击识别按钮的次数
const val PT_camera_iden_click = "PT_camera_iden_click" //用户拍照后选择完裁剪框点击识别按钮的次数
const val PT_screen_shot_iden_click = "PT_gallery_iden_click" //用户选择相册中图片后点击识别按钮的次数


const val PT_flash_click = "PT_flash_click" //用户打开闪光灯的次数

const val PT_camera_click = "PT_camera_click" //用户拍照的次数

const val PT__gallery_click_success = "PT__gallery_click_success" //用户选择相册中图片后成功识别翻译的次数
const val PT__camera_click_success = "PT__camera_click_success" //用户拍照后成功识别翻译的次数

const val PT__camera_click_fail = "PT__camera_click_fail" //用户拍照后失败的次数
const val PT__gallery_click_fail = "PT__gallery_click_fail" //用户选择相册中图片后失败的次数

const val Trans_start_translate = "Trans_start_translate"
const val Trans_translate_success = "Trans_translate_success"
const val Trans_translate_failure = "Trans_translate_failure"

const val language = "language"
const val moduleType = "moduleType"

const val modulePic = "modulePic"
const val errorMessage = "errorMessage"
/*参数：errorcode
2 ：网络问题
3： 识别超时
4:   翻译错误*/
const val errorcode = "errorcode"
const val NETWORK_PROBLEM = "network_problem"
const val TIMEOUT = "timeout"
const val TRANSLATION_FAIL = "translation_fail"

const val PT_screen_shot_click = "PT_screen_shot_click" //截屏翻译球点击事件

const val NT_notification_click = "NT_notification_click"

const val PT_exit = "PT_exit"
const val PT_lan_click_switch = "PT_lan_click_switch"

const val TB_screen_trans_dialog = "TB_screen_trans_dialog"

const val PT_camera_refresh = "PT_camera_refresh"

const val PT_camera_contrast = "PT_camera_contrast"

const val PT_contrast_copy = "PT_contrast_copy"

const val PT_contrast_edit = "PT_contrast_edit"

const val PT_edit_edit = "PT_edit_edit"
const val PT_edit_translate = "PT_edit_translate"
const val PT_edit_copy = "PT_edit_copy"
